yt.frontends.fits.data_structures.FITSDataset.find_field_values_at_points — The yt Project 3.2-dev documentation

# yt.frontends.fits.data_structures.FITSDataset.find_field_values_at_points

`FITSDataset.` `find_field_values_at_points`(fields, coords)

  Returns the values [field1, field2,...] of the fields at the given [(x1, y1, z2), (x2, y2, z2),...] points. Returns a list of field values in the same order as the input fields.

  This is quite slow right now as it creates a new data object for each point. If an optimized version exists on the Index object we’ll use that instead.